import React, { useEffect, useState } from 'react';

import Picker from '../Picker/Picker'
import TextInput from '../TextInput/TextInput'

import { PickerItems } from '../../interfaces/PickerProps/PickerProps.interface';
import { SearchFilterFormProps } from "../../interfaces/SearchFilterFormProps/SearchFilterFormProps.interface";

import CitiesService from "../../services/CitiesService";
import TypesService from '../../services/TypesService'
import SelectDatePicker from '../SelectDatePicker/SelectDatePicker';
import { Platform } from 'react-native';

export default function SearchFilterForm({ searchParams, onChangeField }: SearchFilterFormProps) {
	const [cities, setCities] = useState<PickerItems[]>([] as PickerItems[])
	const [types, setTypes] = useState<PickerItems[]>([] as PickerItems[])
	const [showDatePicker, setShowDatePicker] = useState(false)
	const [selectedDate, setSelectedDate] = useState(new Date())
	const [showPlaceholder, setShowPlaceholder] = useState(true)

	async function setUp() {
		const [_cities, _types] = await Promise.all([
			CitiesService.findCities(),
			TypesService.findTypes()
		])
		setCities(_cities.map(({ id, name }) => ({ label: name, value: id })));
		setTypes(_types.map(({ id, name }) => ({ label: name, value: id })));
		if (searchParams.date) {
			const year = Number(searchParams.date.split("/")[2])
			const month = Number(searchParams.date.split("/")[1])
			const day = Number(searchParams.date.split("/")[0])

			setSelectedDate(new Date(year, month, day))
			setShowPlaceholder(false)
		}
	}

	useEffect(() => {
		setUp();
	}, [])

	const handleDatePicker = () => {
		setShowDatePicker(state => !state)
	}

	const handleDateChange = (event: any, date: Date) => {
		if (Platform.OS === 'android') {
			setShowDatePicker(false) //necessario pra tirar duplo clique android
		}
		if (date) {
			setSelectedDate(date)
			setShowPlaceholder(false)
			const formattedDate = date.getDate() + "/" + date.getMonth() + "/" + date.getFullYear()
			onChangeField({ name: 'date', value: formattedDate }) //antes era 30/10/2020 - formatar? ou isoString()
		}
		setShowDatePicker(false)
	}

	return (
		<>
			<Picker
				items={cities}
				iconLeft="location-on"
				selectedValue={searchParams.city.id}
				onValueChange={(value: string, i: any) => onChangeField({ name: 'city', value: { id: value, name: cities[i].label } })}
			/>

			<Picker
				items={types}
				iconLeft="home"
				selectedValue={searchParams.place.id}
				onValueChange={(value: string, i: any) => onChangeField({ name: 'place', value: { id: value, name: types[i].label } })}
			/>

			<SelectDatePicker
				onPress={handleDatePicker}
				onChange={handleDateChange}
				opened={showDatePicker}
				iconLeft="today"
				placeholder="Quando"
				selectedDate={selectedDate}
				showPlaceholder={showPlaceholder}
			/>

			<TextInput
				iconLeft="people"
				placeholder="Pessoas"
				onChangeText={(value: React.SetStateAction<string>) => onChangeField({ name: 'people', value })}
				value={searchParams.people}
			/>
		</>
	);
}
